@@ -1,4 +1,4 @@
-#' apply a dictionary to a dfm
+#' Apply a dictionary to a dfm
 #' 
 #' Apply a dictionary to a dfm by looking up all dfm features for matches in a a
 #' set of \link{dictionary} values, and replace those features with a count of
@@ -29,6 +29,7 @@
 #'   multi-word patterns is to apply \code{\link{tokens_lookup}} to the tokens,
 #'   and then construct the dfm.
 #' @keywords dfm
+#' @seealso dfm_replace
 #' @examples
 #' myDict <- dictionary(list(christmas = c("Christmas", "Santa", "holiday"),
 #'                           opposition = c("Opposition", "reject", "notincorpus"),
@@ -56,7 +57,8 @@
 #' dfm_lookup(myDfm, myDict, nomatch = "_UNMATCHED")
 #' 
 dfm_lookup <- function(x, dictionary, levels = 1:5,
-                       exclusive = TRUE, valuetype = c("glob", "regex", "fixed"), 
+                       exclusive = TRUE, 
+                       valuetype = c("glob", "regex", "fixed"), 
                        case_insensitive = TRUE,
                        capkeys = !exclusive,
                        nomatch = NULL,
@@ -64,10 +66,21 @@ dfm_lookup <- function(x, dictionary, levels = 1:5,
     UseMethod("dfm_lookup")
 }
  
-#' @noRd
+#' @export
+dfm_lookup.default <- function(x, dictionary, levels = 1:5,
+                           exclusive = TRUE, 
+                           valuetype = c("glob", "regex", "fixed"), 
+                           case_insensitive = TRUE,
+                           capkeys = !exclusive,
+                           nomatch = NULL,
+                           verbose = quanteda_options("verbose")) {
+    stop(friendly_class_undefined_message(class(x), "dfm_lookup"))
+}
+
 #' @export
 dfm_lookup.dfm <- function(x, dictionary, levels = 1:5,
-                           exclusive = TRUE, valuetype = c("glob", "regex", "fixed"), 
+                           exclusive = TRUE, 
+                           valuetype = c("glob", "regex", "fixed"), 
                            case_insensitive = TRUE,
                            capkeys = !exclusive,
                            nomatch = NULL,
@@ -76,6 +89,8 @@ dfm_lookup.dfm <- function(x, dictionary, levels = 1:5,
         stop("dictionary must be a dictionary object")
     
     x <- as.dfm(x)
+    if (!nfeat(x) || !ndoc(x)) return(x)
+
     dictionary <- flatten_dictionary(dictionary, levels)
     valuetype <- match.arg(valuetype)
     attrs <- attributes(x)
@@ -90,9 +105,11 @@ dfm_lookup.dfm <- function(x, dictionary, levels = 1:5,
         catm("applying a dictionary consisting of ", length(dictionary), " key", 
              if (length(dictionary) > 1L) "s" else "", "\n", sep="")
     
-    index <- index_types(types, valuetype, case_insensitive) # index types before the loop
+    # index types before the loop
+    index <- index_types(types, valuetype, case_insensitive) 
     for (h in seq_along(dictionary)) {
-        values <- as.list(stri_replace_all_fixed(dictionary[[h]], ' ', attr(x, 'concatenator')))
+        values <- as.list(stri_replace_all_fixed(dictionary[[h]], ' ', 
+                                                 attr(x, 'concatenator')))
         values_temp <- unlist(regex2id(values, index = index))
         values_id <- c(values_id, values_temp)
         keys_id <- c(keys_id, rep(h, length(values_temp)))
@@ -103,9 +120,10 @@ dfm_lookup.dfm <- function(x, dictionary, levels = 1:5,
             keys <- char_toupper(keys)
         if (exclusive) {
             if (!is.null(nomatch)) {
-                values_id_nomatch <- setdiff(seq_len(nfeature(x)), values_id)
+                values_id_nomatch <- setdiff(seq_len(nfeat(x)), values_id)
                 values_id <- c(values_id, values_id_nomatch)
-                keys_id <- c(keys_id, rep(max(keys_id) + 1, length(values_id_nomatch)))
+                keys_id <- c(keys_id, rep(max(keys_id) + 1, 
+                                          length(values_id_nomatch)))
                 keys <- c(keys, nomatch[1])
             }
             x <- x[,values_id]
@@ -113,7 +131,8 @@ dfm_lookup.dfm <- function(x, dictionary, levels = 1:5,
             colnames(x) <- cols_new
             # merge identical keys and add non-existent keys
             result <- dfm_select(dfm_compress(x, margin = 'features'), 
-                                 as.dfm(rbind(structure(rep(0, length(keys)), names = keys))))
+                                 as.dfm(rbind(structure(rep(0, length(keys)), 
+                                                        names = keys))))
         } else {
             if (!is.null(nomatch))
                 warning("nomatch only applies if exclusive = TRUE")
@@ -126,7 +145,8 @@ dfm_lookup.dfm <- function(x, dictionary, levels = 1:5,
     } else {
         if (exclusive) {
             if (!is.null(nomatch)) {
-                restul <- cbind(x[,0], as.dfm(cbind(structure(ntoken(x), names = nomatch))))
+                result <- cbind(x[,0], as.dfm(cbind(structure(ntoken(x), 
+                                                              names = nomatch))))
             } else {
                 result <- x[,0] # dfm without features
             }
@@ -140,4 +160,3 @@ dfm_lookup.dfm <- function(x, dictionary, levels = 1:5,
     attributes(result, FALSE) <- attrs
     return(result)
 }
-
