@@ -1,4 +1,4 @@
-#' select or remove tokens from a tokens object
+#' Select or remove tokens from a tokens object
 #' 
 #' These function select or discard tokens from a \link{tokens} objects.  For 
 #' convenience, the functions \code{tokens_remove} and \code{tokens_keep} 
@@ -67,6 +67,16 @@ tokens_select <- function(x, pattern, selection = c("keep", "remove"),
     UseMethod("tokens_select")
 }
 
+#' @export
+tokens_select.default <- function(x, pattern = NULL, 
+                                  selection = c("keep", "remove"), 
+                                  valuetype = c("glob", "regex", "fixed"),
+                                  case_insensitive = TRUE, padding = FALSE, window = 0,
+                                  min_nchar = 1L, max_nchar = 79L,
+                                  verbose = quanteda_options("verbose")) {
+    stop(friendly_class_undefined_message(class(x), "tokens_select"))
+}
+
 #' @rdname tokens_select
 #' @noRd
 #' @importFrom RcppParallel RcppParallelLibs
@@ -105,7 +115,7 @@ tokens_select.tokens <- function(x, pattern = NULL,
                                  valuetype = c("glob", "regex", "fixed"),
                                  case_insensitive = TRUE, padding = FALSE, window = 0,
                                  min_nchar = 1L, max_nchar = 79L,
-                                 verbose = quanteda_options("verbose"), ...) {
+                                 verbose = quanteda_options("verbose")) {
     
     selection <- match.arg(selection)
     valuetype <- match.arg(valuetype)
@@ -154,7 +164,7 @@ tokens_select.tokens <- function(x, pattern = NULL,
 
 #' @rdname tokens_select
 #' @param ... additional arguments passed by \code{tokens_remove} and
-#'   \code{tokens_keep} to \code{tokens_select}.  Cannot include
+#'   \code{tokens_keep} to \code{tokens_select}. Cannot include
 #'   \code{selection}.
 #' @export
 #' @examples
@@ -172,7 +182,6 @@ tokens_remove <- function(x, ...) {
     tokens_select(x, ..., selection = "remove")
 }
 
-
 #' @rdname tokens_select
 #' @export
 #' @examples 
@@ -184,4 +193,3 @@ tokens_keep <- function(x, ...) {
     }
     tokens_select(x, ..., selection = "keep")
 }
-
