@@ -6,7 +6,7 @@ test_that("tokens_compound join tokens correctly", {
              "aaa bbb ccc ddd eee fff ggg", "a_b b_c c_d d_e e_f f_g") 
     toks <- tokens(txt)
     seqs <- tokens(c("a b", "C D", "aa* bb*", "eEE FFf", "d_e e_f"), 
-                   hash = FALSE, what = "fastestword")
+                   what = "fastestword")
     expect_equivalent(
         as.list(tokens_compound(toks, seqs, valuetype = "glob", case_insensitive = TRUE)),
         list(c("a_b", "c_d", "e", "f", "g"),
@@ -26,7 +26,7 @@ test_that("tokens_compound join tokens correctly", {
     )
     
     seqs_fixed <- tokens(c("a b", "C D", "aa bb", "eEE FFf", "d_e e_f"), 
-                         hash = FALSE, what = "fastestword")
+                         what = "fastestword")
     expect_equivalent(
         as.list(tokens_compound(toks, seqs_fixed, valuetype = "glob", case_insensitive = TRUE)),
         list(c("a_b", "c_d", "e", "f", "g"),
@@ -51,7 +51,7 @@ test_that("tokens_compound join a sequences of sequences", {
     txt <- c("a b c d e f g", "A B C D E F G") 
     toks <- tokens(txt)
     seqs <- tokens(c("a b", "b c d", "E F", "F G"), 
-                   hash = FALSE, what = "fastestword")
+                   what = "fastestword")
     expect_equal(
         as.list(tokens_compound(toks, seqs, valuetype = "glob", case_insensitive = TRUE, join = TRUE)),
         list(text1 = c("a_b_c_d", "e_f_g"),
@@ -180,4 +180,4 @@ test_that("tokens_compound works as expected with dictionaries", {
 test_that("tokens_compound error when dfm is given, #1006", {
     toks <- tokens('a b c')
     expect_error(tokens_compound(toks, dfm('b c d')))
-})
\ No newline at end of file
+})
